@@ -490,6 +490,9 @@ PJ_DEF(pj_status_t) pjsip_regc_release_transport(pjsip_regc *regc)
         pjsip_transport_dec_ref(regc->last_transport);
         regc->last_transport = NULL;
     }
+    if (regc->info_transport) {
+        regc->info_transport = NULL;
+    }
     return PJ_SUCCESS;
 }
 
